@@ -62,19 +62,35 @@ Licensed under the Apache License, Version 2.0: http://www.apache.org/licenses/L
 package LabKey::Query;
 
 use strict;
-use LWP::UserAgent;
-use HTTP::Request;
 use JSON;
 use Data::Dumper;
 use FileHandle;
 use File::Spec;
 use File::HomeDir;
 use Carp;
+
+
+# Force all SSL connections to use TLSv1 or greater protocol. This is required for 
+# MacOSX and older Windows workstations.
+# 
+# Credit to @chrisrth on stackoverflow (http://stackoverflow.com/a/20305596)
+# See https://www.labkey.org/issues/home/Developer/issues/details.view?issueId=22146
+# for more information.
+# 
+use IO::Socket::SSL;
+my $context = new IO::Socket::SSL::SSL_Context(
+	SSL_version => 'tlsv1'
+);
+IO::Socket::SSL::set_default_context($context);
+
+use LWP::UserAgent;
+use HTTP::Request;
 use URI;
 
+
 use vars qw($VERSION);
 
-our $VERSION = "1.04";
+our $VERSION = "1.05";
 
 
 
